.. change::
   :tags: bug, oracle
   :tickets: 4506
   :versions: 1.3.0

   Added support for reflection of the :class:`.NCHAR` datatype to the Oracle
   dialect, and added :class:`.NCHAR` to the list of types exported by the
   Oracle dialect.

